@section('title', 'Visi Misi')
@extends('Frontend.Layouts.app2')
@section('content')
    <x-header-section-page title="Visi Misi Sekolah Tinggi Ilmu Pertanian Sriwigama" breadcrumb-home="Home"
        breadcrumb-current="Visi Misi" />

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Menjadi Sekolah Tinggi Ilmu Pertanian yang Unggul dalam bidang urban farming berbasis kewirausahaan
                    dikawasan Asia Tenggara pada tahun 2048
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>
                        Menjalankan pendidikan dan pengajaran yang unggul dalam bidang urban farming menghasilkan Sarjana
                        Pertanian yang professional,inovatif , berwawasan global, respon terhadap perkembangan Iptek serta
                        tidak meninggalkan nilai-nilai luhur kepribadian bangsa Indonesia
                    </li>
                    <li>
                        Melaksanakan penelitian dan publiasi ilmiah berbasis IPTEK pertanian yang dapat diaplikasi dalam
                        pembangunan
                    </li>
                    <li>
                        Melaksanakan pengabdian pada masyarakat yang berkontribusi dalam pengembangan IPTEK yang dapat
                        diaplikasi dalam pembangunan.
                    </li>
                    <li>
                        Meningkatkan sistem tata kelola perguruan tinggi yang bersih, akuntable, dan transparan.
                        Menjalin kerjasama dengan pemerintah dan swasta baik dalam dan luar negeri
                    </li>
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-secondary py-8 rounded-lg">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold text-white mb-3">Bergabunglah Bersama
                        Sekolah Tinggi Ilmu Pertanian Sriwigama
                    </h2>
                    <p data-aos="fade-up" class="text-white font-dmsans mb-5 mx-6">"Bangun karier di dunia kebidanan dengan
                        ilmu,
                        keterampilan, dan keimanan! Sekolah Tinggi Ilmu Pertanian Sriwigama siap membimbingmu menuju masa
                        depan yang
                        gemilang."</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
@endsection
