<div class="relative md:max-h-screen h-[1028px] w-auto bg-center md:bg-contain bg-cover bg-no-repeat flex flex-col items-center justify-center overflow-hidden bg-hero"
    style="background-color: #066B2B;" data-aos="fade-up">
</div>

<!--<div class="w-full h-[40px] py-6 flex items-center bg-accent text-white overflow-hidden" data-aos="fade-down">-->
<!--    <div class="w-full whitespace-nowrap animate-marquee flex items-center">-->
<!--        <span class="font-poppins mx-4 text-[40px] font-bold uppercase" data-aos="flip-left">Sekolah Tinggi Ilmu Pertanian-->
<!--            Sriwigama</span>-->
<!--        <img src="{{ asset('./images/logo/logo1.png') }}" alt="Logo" class="h-[40px] w-auto mx-4"-->
<!--            data-aos="flip-left">-->
<!--        <span class="font-poppins mx-4 text-[40px] font-bold uppercase" data-aos="flip-left">Sekolah Tinggi Ilmu-->
<!--            Pertanian Sriwigama</span>-->
<!--        <img src="{{ asset('./images/logo/logo1.png') }}" alt="Logo" class="h-[40px] w-auto mx-4"-->
<!--            data-aos="flip-left">-->
<!--        <span class="font-poppins mx-4 text-[40px] font-bold uppercase" data-aos="flip-left">Sekolah Tinggi Ilmu-->
<!--            Pertanian Sriwigama</span>-->
<!--        <img src="{{ asset('./images/logo/logo1.png') }}" alt="Logo" class="h-[40px] w-auto mx-4"-->
<!--            data-aos="flip-left">-->
<!--        <span class="font-poppins mx-4 text-[40px] font-bold uppercase" data-aos="flip-left">Sekolah Tinggi Ilmu-->
<!--            Pertanian Sriwigama</span>-->
<!--    </div>-->
<!--</div>-->
