@section('title', 'Sejarah')
@extends('Frontend.Layouts.app2')
@section('content')
    <x-header-section-page title="Sejarah Sekolah Tinggi Ilmu Pertanian Sriwigama" breadcrumb-home="Home"
        breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up"
            class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px] bg-white shadow-xl shadow rounded-lg p-6">
            <p class="first-line:pl-5">


                Sekolah Tinggi ilmu Pertanian (STIPER) Sriwigama berdiri pada tahun ajaran 1993/1994 dibawah payung hukum
                yayasan Sriwigama (dahulu) dan sekarang Yayasan Anugerah Sriwigama. Izin operasional berdasarkan Surat
                Keputusan Direktorat Jenderal Pendidikan Tinggi N0. 18/D.O/1993 Tanggal 11 September 1993, hanya memiliki 1
                Jurusan yaitu Budidaya Pertanian dengan progam studi Perkebunan. Pada tanggal 5 Pebruari 1996 berdasarkan
                surat keputusan Dirjen Dikti No. 30/Dikti/Kep/1996 STIPER Sriwigama kembali di izinkan membuka dua jurusan
                yaitu Jurusan Kehutanan dengan program studi Budidaya Hutan, dan Jurusan Sosial Ekonomi Pertanian dengan
                program studi Agribisnis. Ketiga Program studi di STIPER Sriwigama berstatus Terdaftar pada Departemen P & K
                Direktorat Jendral Pendidikan Tinggi berdasarkan surat keputusan Direktorat Jenderal Pendidikan Tinggi
                hingga tahun 2010. Sejak tahun tersebut satu demi satu program studi di STIPER Sriwigama berstatus
                terakreditasi. Peringkat akreditasi program studi hingga tahun 2025 adalah program studi Agroteknologi
                terakreditasi B berdasarkan Keputusan BAN-PT No 5373/SK/BAN-PT/Ak-PPJ/S/IX/2020, sedangkan program studi
                Kehutanan terakreditasi Baik berdasarkan Keputusan BAN-PT No 8954/SK/BAN-PT/Ak.KP/S/XI/2022 dan Program
                Studi Agribisnis akreditasi Baik, berdasarkan Keputusan BAN-PT No 7232/SK/BAN-PT/Ak-KP/S/X/2022. Institusi
                terakreditasi Baik berdasarkan keputusan BAN-PT No 1052/SK/BAN-PT/Akred/PT/XII/2020.
            </p>
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-primary my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">DAFTAR
                SEKARANG</h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
                Dapatkan pendidikan berkualitas dan pengalaman praktis di dunia pertanian bersama STIPER Sriwigama untuk
                masa
                depan yang cerah!
            </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
