<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="description"
        content="STIPER Sriwigama merupakan perguruan tinggi yang berfokus pada bidang pertanian, khususnya agribisnis, agroteknologi, dan kehutanan. Didirikan pada tahun 1993, STIPER Sriwigama bertujuan untuk mencetak lulusan yang profesional, inovatif, dan siap berkontribusi dalam pengembangan pertanian. Dengan fasilitas modern dan pengajaran yang berkualitas, STIPER Sriwigama mendukung pengembangan pertanian yang berkelanjutan dan kewirausahaan di sektor pertanian." />
    <meta name="keywords"
        content="Sekolah Tinggi Ilmu Pertanian Sriwigama, pendidikan pertanian, agribisnis, agroteknologi, program studi pertanian,
         kampus pertanian di Palembang, fakultas pertanian, biaya kuliah pertanian, pendaftaran STIPER Sriwigama, kuliah agribisnis,
          kewirausahaan pertanian, penelitian pertanian, kampus dengan fasilitas modern, pengembangan karir pertanian, mahasiswa pertanian,
           alumni pertanian, agribisnis di Indonesia, agrikultur berkelanjutan, pertanian dan teknologi, pendidikan tinggi pertanian di Palembang,
            Universitas Sriwijaya, Universitas Negeri Palembang, Universitas Indo Global Mandiri">

    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title>@yield('title') &mdash; Sekolah Tinggi Ilmu Pertanian Sriwigama(Kelas Karyawan)</title>
    <meta property="og:title" content="Sekolah Tinggi Ilmu Pertanian Sriwigama (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://stipersriwigama.info/">
    <meta property="og:image" content="https://stipersriwigama.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description"
        content="Sekolah Tinggi Ilmu Pertanian Sriwigama merupakan perguruan tinggi yang berfokus pada pendidikan pertanian. Menyediakan program studi Agribisnis, Agroteknologi, dan Kehutanan dengan kelas reguler dan kelas karyawan. Dilengkapi dengan fasilitas modern dan tenaga pengajar berkompeten, STIPER Sriwigama menawarkan pendidikan berkualitas dengan biaya terjangkau di Palembang." />
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@stipersriwigama">
    <meta name="twitter:site" content="@stipersriwigama">
    <meta name="twitter:title" content="Sekolah Tinggi Ilmu Pertanian Sriwigama | Pendidikan Pertanian Berkualitas">
    <meta name="twitter:description"
        content="STIPER Sriwigama menyediakan program pendidikan di bidang pertanian dengan kelas reguler dan kelas karyawan. Program studi Agribisnis, Agroteknologi, dan Kehutanan memberikan peluang bagi mahasiswa untuk berkarir di sektor pertanian dengan biaya terjangkau dan flexible." />
    <meta name="twitter:domain" content="https://stipersriwigama.info/">
    <meta name="twitter:image:src" content="https://stipersriwigama.info/images/background/hero1.png">
    <meta name="author" content="STIPER Sriwigama Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Sekolah Tinggi Ilmu Pertanian Sriwigama">
    <meta name="msapplication-TileColor" content="#9E2A61" />
    <meta name="theme-color" content="#9E2A61" />

    <link rel="apple-touch-icon" sizes="57x57" href="{{ asset('images/favicons/apple-icon-57x57.png') }}">
    <link rel="apple-touch-icon" sizes="60x60" href="{{ asset('images/favicons/apple-icon-60x60.png') }}">
    <link rel="apple-touch-icon" sizes="72x72" href="{{ asset('images/favicons/apple-icon-72x72.png') }}">
    <link rel="apple-touch-icon" sizes="76x76" href="{{ asset('images/favicons/apple-icon-76x76.png') }}">
    <link rel="apple-touch-icon" sizes="114x114" href="{{ asset('images/favicons/apple-icon-114x114.png') }}">
    <link rel="apple-touch-icon" sizes="120x120" href="{{ asset('images/favicons/apple-icon-120x120.png') }}">
    <link rel="apple-touch-icon" sizes="144x144" href="{{ asset('images/favicons/apple-icon-144x144.png') }}">
    <link rel="apple-touch-icon" sizes="152x152" href="{{ asset('images/favicons/apple-icon-152x152.png') }}">
    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset('images/favicons/apple-icon-180x180.png') }}">
    <link rel="icon" type="image/png" sizes="192x192"
        href="{{ asset('images/favicons/android-icon-192x192.png') }}">
    <link rel="icon" type="image/png" sizes="32x32" href="{{ asset('images/favicons/favicons-32x32.png') }}">
    <link rel="icon" type="image/png" sizes="96x96" href="{{ asset('images/favicons/favicons-96x96.png') }}">
    <link rel="icon" type="image/png" sizes="16x16" href="{{ asset('images/favicons/favicons-16x16.png') }}">
    <link rel="manifest" href="images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    {{-- flowbite --}}
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    @yield('content')

    {{-- flowbite --}}
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    {{-- Tempatkan stack scripts --}}
    @stack('scripts')
</body>

</html>
